@@ -9,11 +9,11 @@
 //       SHOULD ONLY CONSIST OF PREPROCESSOR DIRECTIVES
 // -----------------------------------------------------
 
-// pico_cmake_set PICO_PLATFORM=rp2040
-
 #ifndef _BOARDS_GARATRONIC_PYBSTICK26_RP2040_H
 #define _BOARDS_GARATRONIC_PYBSTICK26_RP2040_H
 
+pico_board_cmake_set(PICO_PLATFORM, rp2040)
+
 // For board detection
 #define GARATRONIC_PYBSTICK26_RP2040
 
@@ -70,7 +70,7 @@
 #define PICO_FLASH_SPI_CLKDIV 2 
 #endif
 
-// pico_cmake_set_default PICO_FLASH_SIZE_BYTES = (1 * 1024 * 1024)
+pico_board_cmake_set_default(PICO_FLASH_SIZE_BYTES, (1 * 1024 * 1024))
 #ifndef PICO_FLASH_SIZE_BYTES
 #define PICO_FLASH_SIZE_BYTES (1 * 1024 * 1024)
 #endif
