@@ -9,13 +9,13 @@
 //       SHOULD ONLY CONSIST OF PREPROCESSOR DIRECTIVES
 // -----------------------------------------------------
 
-// pico_cmake_set PICO_PLATFORM=rp2350
+#ifndef _BOARDS_GEN4_RP2350_24_H
+#define _BOARDS_GEN4_RP2350_24_H
 
-#ifndef _BOARDS_GEN4_RP2350_28_H
-#define _BOARDS_GEN4_RP2350_28_H
+pico_board_cmake_set(PICO_PLATFORM, rp2350)
 
 // For board detection
-#define GEN4_RP2350_28
+#define GEN4_RP2350_24
 
 // --- RP2350 VARIANT ---
 #define PICO_RP2350A 0
@@ -71,12 +71,12 @@
 #define PICO_FLASH_SPI_CLKDIV 2
 #endif
 
-// pico_cmake_set_default PICO_FLASH_SIZE_BYTES = (16 * 1024 * 1024)
+pico_board_cmake_set_default(PICO_FLASH_SIZE_BYTES, (16 * 1024 * 1024))
 #ifndef PICO_FLASH_SIZE_BYTES
 #define PICO_FLASH_SIZE_BYTES (16 * 1024 * 1024)
 #endif
 
-// pico_cmake_set_default PICO_RP2350_A2_SUPPORTED = 1
+pico_board_cmake_set_default(PICO_RP2350_A2_SUPPORTED, 1)
 #ifndef PICO_RP2350_A2_SUPPORTED
 #define PICO_RP2350_A2_SUPPORTED 1
 #endif
