@@ -9,13 +9,13 @@
 //       SHOULD ONLY CONSIST OF PREPROCESSOR DIRECTIVES
 // -----------------------------------------------------
 
-// pico_cmake_set PICO_PLATFORM=rp2350
+#ifndef _BOARDS_GEN4_RP2350_24CT_H
+#define _BOARDS_GEN4_RP2350_24CT_H
 
-#ifndef _BOARDS_GEN4_RP2350_32CT_H
-#define _BOARDS_GEN4_RP2350_32CT_H
+pico_board_cmake_set(PICO_PLATFORM, rp2350)
 
 // For board detection
-#define GEN4_RP2350_32CT	// CLB variants are exactly the same in operation
+#define GEN4_RP2350_24CT	// CLB variants are exactly the same in operation
 
 // --- RP2350 VARIANT ---
 #define PICO_RP2350A 0
@@ -71,12 +71,12 @@
 #define PICO_FLASH_SPI_CLKDIV 2
 #endif
 
-// pico_cmake_set_default PICO_FLASH_SIZE_BYTES = (16 * 1024 * 1024)
+pico_board_cmake_set_default(PICO_FLASH_SIZE_BYTES, (16 * 1024 * 1024))
 #ifndef PICO_FLASH_SIZE_BYTES
 #define PICO_FLASH_SIZE_BYTES (16 * 1024 * 1024)
 #endif
 
-// pico_cmake_set_default PICO_RP2350_A2_SUPPORTED = 1
+pico_board_cmake_set_default(PICO_RP2350_A2_SUPPORTED, 1)
 #ifndef PICO_RP2350_A2_SUPPORTED
 #define PICO_RP2350_A2_SUPPORTED 1
 #endif
@@ -107,8 +107,7 @@
 #define LCD_TOUCH_XR        LCD_TOUCH_SDA
 #define LCD_TOUCH_I2C       i2c1
 #define LCD_TOUCH_CTP_FT
-#define LCD_TOUCH_POINTS    5
-#define LCD_TOUCH_MIRROR_Y
+#define LCD_TOUCH_POINTS    2
 
 #define LCD_SD_CLK          10
 #define LCD_SD_CMD          11
