@@ -12,7 +12,7 @@
 #ifndef _BOARDS_HELLBENDER_2350A_DEVBOARD_H
 #define _BOARDS_HELLBENDER_2350A_DEVBOARD_H
 
-// pico_cmake_set PICO_PLATFORM=rp2350
+pico_board_cmake_set(PICO_PLATFORM, rp2350)
 
 // For board detection
 #define HELLBENDER_2350A_DEVBOARD
@@ -22,16 +22,17 @@
 #define HB_2350A_IMU_INT_PIN 1
 #define HB_2350A_USER_QWIIC_SDA_PIN 2
 #define HB_2350A_USER_QWIIC_SCL_PIN 3
-#define HB_2350A_RTC_INT_PIN 8
+#define HB_2350A_RTC_INT_PIN 22
 #define HB_2350A_SDCARD_CS_PIN 9
 #define HB_2350A_LORA_IO1_PIN 10
 #define HB_2350A_LORA_IO3_PIN 11
-#define HB_2350A_LORA_CS_PIN 21
+#define HB_2350A_LORA_CS_PIN 28
+#define HB_2350A_LORA_BUSY_PIN 24
+#define HB_2350A_LORA_RESET_PIN 29
 #define HB_2350A_RTC_CLKIN_PIN 22
 #define HB_2350A_IMU_CLKOUT_PIN 23
-#define HB_2350A_LORA_BUSY_PIN 24
-#define HB_2350A_FUSB307_INT_PIN 25
-#define HB_2350A_LORA_RESET_PIN 29
+#define HB_2350A_FUSB307_INT_PIN 21
+#define HB_2350A_BQ25792_INT_PIN 8
 
 // --- UART ---
 // Note, conflicts with HSTX range
@@ -45,7 +46,11 @@
 #define PICO_DEFAULT_UART_RX_PIN 13
 #endif
 
-// no PICO_DEFAULT_LED_PIN
+// --- LED ---
+#ifndef PICO_DEFAULT_LED_PIN
+#define PICO_DEFAULT_LED_PIN 25
+#endif
+
 // no PICO_DEFAULT_WS2812_PIN
 
 // --- I2C ---
@@ -72,9 +77,8 @@
 #ifndef PICO_DEFAULT_SPI_RX_PIN
 #define PICO_DEFAULT_SPI_RX_PIN 20
 #endif
-#ifndef PICO_DEFAULT_SPI_CSN_PIN
-#define PICO_DEFAULT_SPI_CSN_PIN 21
-#endif
+// multiple devices, so this doesn't make much sense
+// no PICO_DEFAULT_SPI_CSN_PIN
 
 // --- FLASH ---
 
@@ -84,14 +88,14 @@
 #define PICO_FLASH_SPI_CLKDIV 2
 #endif
 
-// pico_cmake_set_default PICO_FLASH_SIZE_BYTES = (16 * 1024 * 1024)
+pico_board_cmake_set_default(PICO_FLASH_SIZE_BYTES, (16 * 1024 * 1024))
 #ifndef PICO_FLASH_SIZE_BYTES
 #define PICO_FLASH_SIZE_BYTES (16 * 1024 * 1024)
 #endif
 // --- RP2350 VARIANT ---
 #define PICO_RP2350A 1
 
-// pico_cmake_set_default PICO_RP2350_A2_SUPPORTED = 1
+pico_board_cmake_set_default(PICO_RP2350_A2_SUPPORTED, 1)
 #ifndef PICO_RP2350_A2_SUPPORTED
 #define PICO_RP2350_A2_SUPPORTED 1
 #endif
