@@ -11,11 +11,11 @@
 
 // This header may be included by other board headers as "boards/melopero_perpetuo_rp2350_lora.h"
 
-// pico_cmake_set PICO_PLATFORM=rp2350
-
 #ifndef _BOARDS_MELOPERO_PERPETUO_RP2350_LORA_H
 #define _BOARDS_MELOPERO_PERPETUO_RP2350_LORA_H
 
+pico_board_cmake_set(PICO_PLATFORM, rp2350)
+
 // For board detection
 #define MELOPERO_PERPETUO_RP2350_LORA
 
@@ -75,14 +75,14 @@
 #define PICO_FLASH_SPI_CLKDIV 2
 #endif
 
-// pico_cmake_set_default PICO_FLASH_SIZE_BYTES = (8 * 1024 * 1024)
+pico_board_cmake_set_default(PICO_FLASH_SIZE_BYTES, (8 * 1024 * 1024))
 #ifndef PICO_FLASH_SIZE_BYTES
 #define PICO_FLASH_SIZE_BYTES (8 * 1024 * 1024)
 #endif
 
 
 
-// pico_cmake_set_default PICO_RP2350_A2_SUPPORTED = 1
+pico_board_cmake_set_default(PICO_RP2350_A2_SUPPORTED, 1)
 #ifndef PICO_RP2350_A2_SUPPORTED
 #define PICO_RP2350_A2_SUPPORTED 1
 #endif
