@@ -11,11 +11,11 @@
 
 // This header may be included by other board headers as "boards/pico2.h"
 
-// pico_cmake_set PICO_PLATFORM=rp2350
-
 #ifndef _BOARDS_PICO2_H
 #define _BOARDS_PICO2_H
 
+pico_board_cmake_set(PICO_PLATFORM, rp2350)
+
 // For board detection
 #define RASPBERRYPI_PICO2
 
@@ -75,7 +75,7 @@
 #define PICO_FLASH_SPI_CLKDIV 2
 #endif
 
-// pico_cmake_set_default PICO_FLASH_SIZE_BYTES = (4 * 1024 * 1024)
+pico_board_cmake_set_default(PICO_FLASH_SIZE_BYTES, (4 * 1024 * 1024))
 #ifndef PICO_FLASH_SIZE_BYTES
 #define PICO_FLASH_SIZE_BYTES (4 * 1024 * 1024)
 #endif
@@ -93,7 +93,7 @@
 #define PICO_VSYS_PIN 29
 #endif
 
-// pico_cmake_set_default PICO_RP2350_A2_SUPPORTED = 1
+pico_board_cmake_set_default(PICO_RP2350_A2_SUPPORTED, 1)
 #ifndef PICO_RP2350_A2_SUPPORTED
 #define PICO_RP2350_A2_SUPPORTED 1
 #endif
