@@ -11,14 +11,17 @@
 
 // This header may be included by other board headers as "boards/pimoroni_pico_plus2_rp2350.h"
 
-// pico_cmake_set PICO_PLATFORM=rp2350
-
 #ifndef _BOARDS_PIMORONI_PICO_PLUS2_RP2350_H
 #define _BOARDS_PIMORONI_PICO_PLUS2_RP2350_H
 
+pico_board_cmake_set(PICO_PLATFORM, rp2350)
+
 // For board detection
 #define PIMORONI_PICO_PLUS2_RP2350
 
+// --- RP2350 VARIANT ---
+#define PICO_RP2350A 0
+
 // --- BOARD SPECIFIC ---
 #define SPCE_SPI 0
 #define SPCE_TX_MISO_PIN 32
@@ -83,7 +86,7 @@
 #define PICO_FLASH_SPI_CLKDIV 2
 #endif
 
-// pico_cmake_set_default PICO_FLASH_SIZE_BYTES = (16 * 1024 * 1024)
+pico_board_cmake_set_default(PICO_FLASH_SIZE_BYTES, (16 * 1024 * 1024))
 #ifndef PICO_FLASH_SIZE_BYTES
 #define PICO_FLASH_SIZE_BYTES (16 * 1024 * 1024)
 #endif
@@ -99,7 +102,7 @@
 #define PICO_VSYS_PIN 43
 #endif
 
-// pico_cmake_set_default PICO_RP2350_A2_SUPPORTED = 1
+pico_board_cmake_set_default(PICO_RP2350_A2_SUPPORTED, 1)
 #ifndef PICO_RP2350_A2_SUPPORTED
 #define PICO_RP2350_A2_SUPPORTED 1
 #endif
