@@ -9,11 +9,11 @@
 //       SHOULD ONLY CONSIST OF PREPROCESSOR DIRECTIVES
 // -----------------------------------------------------
 
-// pico_cmake_set PICO_PLATFORM=rp2040
-
 #ifndef _BOARDS_PIMORONI_PICOLIPO_4MB_H
 #define _BOARDS_PIMORONI_PICOLIPO_4MB_H
 
+pico_board_cmake_set(PICO_PLATFORM, rp2040)
+
 // For board detection
 #define PIMORONI_PICOLIPO_4MB
 
@@ -74,7 +74,7 @@
 #define PICO_FLASH_SPI_CLKDIV 2
 #endif
 
-// pico_cmake_set_default PICO_FLASH_SIZE_BYTES = (4 * 1024 * 1024)
+pico_board_cmake_set_default(PICO_FLASH_SIZE_BYTES, (4 * 1024 * 1024))
 #ifndef PICO_FLASH_SIZE_BYTES
 #define PICO_FLASH_SIZE_BYTES (4 * 1024 * 1024)
 #endif
