@@ -11,11 +11,11 @@
 
 // This header may be included by other board headers as "boards/pimoroni_tiny2350.h"
 
-// pico_cmake_set PICO_PLATFORM=rp2350
-
 #ifndef _BOARDS_PIMORONI_TINY2350_H
 #define _BOARDS_PIMORONI_TINY2350_H
 
+pico_board_cmake_set(PICO_PLATFORM, rp2350)
+
 // For board detection
 #define PIMORONI_TINY2350
 #define PIMORONI_TINY2350_8MB
@@ -84,12 +84,12 @@
 #define PICO_FLASH_SPI_CLKDIV 2
 #endif
 
-// pico_cmake_set_default PICO_FLASH_SIZE_BYTES = (4 * 1024 * 1024)
+pico_board_cmake_set_default(PICO_FLASH_SIZE_BYTES, (4 * 1024 * 1024))
 #ifndef PICO_FLASH_SIZE_BYTES
 #define PICO_FLASH_SIZE_BYTES (4 * 1024 * 1024)
 #endif
 
-// pico_cmake_set_default PICO_RP2350_A2_SUPPORTED = 1
+pico_board_cmake_set_default(PICO_RP2350_A2_SUPPORTED, 1)
 #ifndef PICO_RP2350_A2_SUPPORTED
 #define PICO_RP2350_A2_SUPPORTED 1
 #endif
