@@ -14,11 +14,11 @@
 //
 // This header may be included by other board headers as "boards/solderparty_rp2040_stamp.h"
 
-// pico_cmake_set PICO_PLATFORM=rp2040
-
 #ifndef _BOARDS_SOLDERPARTY_RP2040_STAMP_H
 #define _BOARDS_SOLDERPARTY_RP2040_STAMP_H
 
+pico_board_cmake_set(PICO_PLATFORM, rp2040)
+
 // For board detection
 #define SOLDERPARTY_RP2040_STAMP
 
@@ -73,7 +73,7 @@
 #define PICO_FLASH_SPI_CLKDIV 2
 #endif
 
-// pico_cmake_set_default PICO_FLASH_SIZE_BYTES = (8 * 1024 * 1024)
+pico_board_cmake_set_default(PICO_FLASH_SIZE_BYTES, (8 * 1024 * 1024))
 #ifndef PICO_FLASH_SIZE_BYTES
 #define PICO_FLASH_SIZE_BYTES (8 * 1024 * 1024)
 #endif
