@@ -14,11 +14,11 @@
 //
 // This header may be included by other board headers as "boards/sparkfun_promicro.h"
 
-// pico_cmake_set PICO_PLATFORM=rp2040
-
 #ifndef _BOARDS_SPARKFUN_PROMICRO_H
 #define _BOARDS_SPARKFUN_PROMICRO_H
 
+pico_board_cmake_set(PICO_PLATFORM, rp2040)
+
 // For board detection
 #define SPARKFUN_PROMICRO
 
@@ -75,7 +75,7 @@
 #endif
 
 // board has 16M onboard flash
-// pico_cmake_set_default PICO_FLASH_SIZE_BYTES = (16 * 1024 * 1024)
+pico_board_cmake_set_default(PICO_FLASH_SIZE_BYTES, (16 * 1024 * 1024))
 #ifndef PICO_FLASH_SIZE_BYTES
 #define PICO_FLASH_SIZE_BYTES (16 * 1024 * 1024)
 #endif
