@@ -14,11 +14,11 @@
 //
 // This header may be included by other board headers as "boards/sparkfun_promicro_rp2350.h"
 
-// pico_cmake_set PICO_PLATFORM=rp2350
-
 #ifndef _BOARDS_SPARKFUN_PROMICRO_RP2350_H
 #define _BOARDS_SPARKFUN_PROMICRO_RP2350_H
 
+pico_board_cmake_set(PICO_PLATFORM, rp2350)
+
 // For board detection
 #define SPARKFUN_PROMICRO_RP2350
 
@@ -73,7 +73,7 @@
 #endif
 
 // board has 16M onboard flash
-// pico_cmake_set_default PICO_FLASH_SIZE_BYTES = (16 * 1024 * 1024)
+pico_board_cmake_set_default(PICO_FLASH_SIZE_BYTES, (16 * 1024 * 1024))
 #ifndef PICO_FLASH_SIZE_BYTES
 #define PICO_FLASH_SIZE_BYTES (16 * 1024 * 1024)
 #endif
@@ -81,7 +81,7 @@
 // --- RP2350 VARIANT ---
 #define PICO_RP2350A 1
 
-// pico_cmake_set_default PICO_RP2350_A2_SUPPORTED = 1
+pico_board_cmake_set_default(PICO_RP2350_A2_SUPPORTED, 1)
 #ifndef PICO_RP2350_A2_SUPPORTED
 #define PICO_RP2350_A2_SUPPORTED 1
 #endif
