@@ -11,11 +11,11 @@
 
 // This header may be included by other board headers as "boards/weact_studio_rp2040_8mb.h"
 
-// pico_cmake_set PICO_PLATFORM=rp2040
-
 #ifndef _BOARDS_WEACT_STUDIO_RP2040_8MB_H
 #define _BOARDS_WEACT_STUDIO_RP2040_8MB_H
 
+pico_board_cmake_set(PICO_PLATFORM, rp2040)
+
 // For board detection
 #define WEACT_STUDIO_RP2040_8MB
 
@@ -75,7 +75,7 @@
 #define PICO_RP2040_B0_SUPPORTED 0
 #endif
 
-// pico_cmake_set_default PICO_FLASH_SIZE_BYTES = (8 * 1024 * 1024)
+pico_board_cmake_set_default(PICO_FLASH_SIZE_BYTES, (8 * 1024 * 1024))
 #ifndef PICO_FLASH_SIZE_BYTES
 #define PICO_FLASH_SIZE_BYTES (8 * 1024 * 1024)
 #endif
