@@ -24,7 +24,8 @@
 #endif
 
 #include "pico.h"
-#include "hardware/regs/intctrl.h"
+// TODO: No hardware/regs/intctrl.h for host yet.
+// #include "hardware/regs/intctrl.h"
 
 /** \file irq.h
  *  \defgroup hardware_irq hardware_irq
@@ -128,7 +129,7 @@ extern "C" {
 typedef void (*irq_handler_t)(void);
 
 static inline void check_irq_param(__unused uint num) {
-    invalid_params_if(HARDWARE_IRQ, num >= NUM_IRQS);
+    invalid_params_if(HARDWARE_IRQ, num >= PICO_NUM_VTABLE_IRQS);
 }
 
 /*! \brief Set specified interrupt's priority
