@@ -73,6 +73,7 @@ static void async_context_task(__unused void *vself) {
         async_context_freertos_release_lock(&self->core);
         __sev(); // it is possible regular code is waiting on a WFE on the other core
     } while (!self->task_should_exit);
+    xSemaphoreGive(self->task_complete_sem);
     vTaskDelete(NULL);
 }
 
@@ -109,19 +110,45 @@ bool async_context_freertos_init(async_context_freertos_t *self, async_context_f
     self->core.type = &template;
     self->core.flags = ASYNC_CONTEXT_FLAG_CALLBACK_FROM_NON_IRQ;
     self->core.core_num = get_core_num();
+#if configSUPPORT_STATIC_ALLOCATION
+    assert(config->task_stack);
+    self->lock_mutex = xSemaphoreCreateRecursiveMutexStatic(&self->lock_mutex_buf);
+    self->work_needed_sem = xSemaphoreCreateBinaryStatic(&self->work_needed_sem_buf);
+    self->task_complete_sem = xSemaphoreCreateBinaryStatic(&self->task_complete_sem_buf);
+    self->timer_handle = xTimerCreateStatic( "async_context_timer",       // Just a text name, not used by the kernel.
+                                             portMAX_DELAY,
+                                             pdFALSE,        // The timers will auto-reload themselves when they expire.
+                                             self,
+                                             timer_handler,
+                                             &self->timer_buf);
+    self->task_handle = xTaskCreateStatic( async_context_task,
+                                           "async_context_task",
+                                           config->task_stack_size,
+                                           self,
+                                           config->task_priority,
+                                           config->task_stack,
+                                           &self->task_buf);
+#else
     self->lock_mutex = xSemaphoreCreateRecursiveMutex();
     self->work_needed_sem = xSemaphoreCreateBinary();
+    self->task_complete_sem = xSemaphoreCreateBinary();
     self->timer_handle = xTimerCreate( "async_context_timer",       // Just a text name, not used by the kernel.
                                     portMAX_DELAY,
                                     pdFALSE,        // The timers will auto-reload themselves when they expire.
                                     self,
                                     timer_handler);
+#endif
 
     if (!self->lock_mutex ||
         !self->work_needed_sem ||
         !self->timer_handle ||
+#if configSUPPORT_STATIC_ALLOCATION
+        !self->task_handle
+#else
         pdPASS != xTaskCreate(async_context_task, "async_context_task", config->task_stack_size, self,
-                config->task_priority, &self->task_handle)) {
+                config->task_priority, &self->task_handle)
+#endif
+    ) {
         async_context_deinit(&self->core);
         return false;
     }
@@ -147,6 +174,9 @@ void async_context_freertos_deinit(async_context_t *self_base) {
     async_context_freertos_t *self = (async_context_freertos_t *)self_base;
     if (self->task_handle) {
         async_context_execute_sync(self_base, end_task_func, self_base);
+        if (self->task_complete_sem) {
+            xSemaphoreTake(self->task_complete_sem, portMAX_DELAY);
+        }
     }
     if (self->timer_handle) {
         xTimerDelete(self->timer_handle, 0);
@@ -157,6 +187,9 @@ void async_context_freertos_deinit(async_context_t *self_base) {
     if (self->work_needed_sem) {
         vSemaphoreDelete(self->work_needed_sem);
     }
+    if (self->task_complete_sem) {
+        vSemaphoreDelete(self->task_complete_sem);
+    }
     memset(self, 0, sizeof(*self));
 }
 
@@ -179,6 +212,9 @@ void async_context_freertos_lock_check(__unused async_context_t *self_base) {
 typedef struct sync_func_call{
     async_when_pending_worker_t worker;
     SemaphoreHandle_t sem;
+#if configSUPPORT_STATIC_ALLOCATION
+    StaticSemaphore_t sem_buf;
+#endif
     uint32_t (*func)(void *param);
     void *param;
     uint32_t rc;
@@ -197,7 +233,11 @@ uint32_t async_context_freertos_execute_sync(async_context_t *self_base, uint32_
     call.worker.do_work = handle_sync_func_call;
     call.func = func;
     call.param = param;
+#if configSUPPORT_STATIC_ALLOCATION
+    call.sem = xSemaphoreCreateBinaryStatic(&call.sem_buf);
+#else
     call.sem = xSemaphoreCreateBinary();
+#endif
     async_context_add_when_pending_worker(self_base, &call.worker);
     async_context_set_work_pending(self_base, &call.worker);
     xSemaphoreTake(call.sem, portMAX_DELAY);
