@@ -98,8 +98,8 @@ typedef struct sync_func_call{
 static void handle_sync_func_call(async_context_t *context, async_when_pending_worker_t *worker) {
     sync_func_call_t *call = (sync_func_call_t *)worker;
     call->rc = call->func(call->param);
-    sem_release(&call->sem);
     async_context_remove_when_pending_worker(context, worker);
+    sem_release(&call->sem);
 }
 #endif
 
@@ -139,7 +139,13 @@ uint32_t async_context_threadsafe_background_execute_sync(async_context_t *self_
     async_context_threadsafe_background_t *self = (async_context_threadsafe_background_t*)self_base;
 #if ASYNC_CONTEXT_THREADSAFE_BACKGROUND_MULTI_CORE
     if (self_base->core_num != get_core_num()) {
-        hard_assert(!recursive_mutex_enter_count(&self->lock_mutex));
+        // This core must not hold the lock mutex, or this cross-core execute would deadlock. It is fine if the other core holds it.
+        // It would be a strange set of circumstances for it to do so, hence the hard_assert
+        
+        // Note that this read of the owner is not synchronized with the other core; however we only
+        // care about it being set to `calling_core`, which the other core will not transition
+        // it either from or to.
+        assert(recursive_mutex_owner(&self->lock_mutex) != lock_get_caller_owner_id());
         sync_func_call_t call = {0};
         call.worker.do_work = handle_sync_func_call;
         call.func = func;
