@@ -4,15 +4,15 @@
  * SPDX-License-Identifier: BSD-3-Clause
  */
 
-#ifndef _PICO_INT64_H
-#define _PICO_INT64_H
+#ifndef _PICO_INT64_OPS_H
+#define _PICO_INT64_OPS_H
 
 #include "pico/types.h"
 
 /** \file int64_ops.h
  *  \defgroup pico_int64_ops pico_int64_ops
  *
- * Optimized replacement implementations of the compiler built-in 64 bit multiplication
+ * \brief Optimized replacement implementations of the compiler built-in 64 bit multiplication
  *
  * This library does not provide any additional functions
 */
