@@ -63,7 +63,7 @@ void program::set_pio_version(const yy::location &l, int version) {
 
 void program::set_clock_div(const yy::location &l, float clock_div) {
     if (clock_div < 1.0f || clock_div >= 65536.0f) {
-        throw syntax_error(l, "clock divider must be between 1 and 65546");
+        throw syntax_error(l, "clock divider must be between 1 and 65535");
     }
     clock_div_int = (uint16_t)clock_div;
     if (clock_div_int == 0) {
@@ -292,7 +292,7 @@ uint instruction::encode(program &program) {
         }
     }
     // note we store the 6th bit of arg2 above the 16 bits of instruction
-    return (((uint) raw.type) << 13u) | (((uint) _delay | (uint) _sideset) << 8u) | (raw.arg1 << 5u) | raw.arg2 | ((raw.arg2 >> 5) << 16);
+    return (((uint) raw.type) << 13u) | (((uint) _delay | (uint) _sideset) << 8u) | (raw.arg1 << 5u) | (raw.arg2 & 0x1fu) | ((raw.arg2 >> 5) << 16);
 }
 
 raw_encoding instruction::raw_encode(program& program) {
